@@ -69,7 +69,7 @@ our %EXPORT_TAGS = (
     private => _export_private(),
 );
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 use constant {
     CONFIG_FILE         => 'dist-mgr.json',
@@ -1089,7 +1089,7 @@ sub _dist_dir_re {
     # CPAN testers
     # Use YAPE::Regex::Explain for details
 
-    return qr/dist-mgr(?:-\d+\.\d+)?(?:-\w+)?$/i;
+    return qr/dist-mgr(?:-\d+\.\d+)?(?:-\w+|_\d+)?$/i;
 }
 sub _validate_git {
     my $sep = $^O =~ /win32/i ? ';' : ':';
